@@ -1,3 +1,4 @@
+import datetime
 from dataclasses import dataclass
 from typing import Any, Callable, List, Optional, Tuple
 
@@ -136,6 +137,12 @@ class Record:
             original_observation_data=original_observation_data,
         )
 
+    def datetime(self) -> datetime.datetime:
+        """Returns this record's datetime."""
+        return datetime.datetime(
+            self.year, self.month, self.day, self.hour, self.minute
+        )
+
 
 def extract_data(message: str, tag: str, later_tags: List[str]) -> Tuple[str, str]:
     if message.startswith(tag):
